@@ -81,14 +81,16 @@ async def test_state_flag_changes(parent, event_loop):
         callback_got = state
 
     t = event_loop.create_task(callback())
-    await asyncio.wait((cmp.run(), t))
+    run_task = event_loop.create_task(cmp.run())
+    await asyncio.wait((run_task, t))
 
     assert callback_got, \
         "Flag wait() should return True which is running component state"
     callback_got = None
 
     t = event_loop.create_task(callback())
-    await asyncio.wait((cmp.terminate(), t))
+    term_t = event_loop.create_task(cmp.terminate())
+    await asyncio.wait((term_t, t))
 
     assert not callback_got, \
         "Flag wait() should return False which is not running component state"
