@@ -29,7 +29,7 @@ def test_function_no_type():
 
 def test_function_default():
     class M(BaseModel):
-        path: FuncPath = FuncPath(example_function)
+        path: FuncPath = example_function
 
     m = M()
     assert m.path() == Result
@@ -47,7 +47,7 @@ async def test_coroutine_no_type():
 @pytest.mark.asyncio
 async def test_coroutine_default():
     class M(BaseModel):
-        path: FuncPath = FuncPath(example_coroutine)
+        path: FuncPath = example_coroutine
 
     m = M()
     assert await m.path() == Result
\ No newline at end of file
